# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from retell import Retell, AsyncRetell
from tests.utils import assert_matches_type
from retell.types import BatchTestResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTests:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_batch_test(self, client: Retell) -> None:
        test = client.tests.create_batch_test(
            response_engine={
                "llm_id": "llm_id",
                "type": "retell-llm",
            },
            test_case_definition_ids=["string"],
        )
        assert_matches_type(BatchTestResponse, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_batch_test_with_all_params(self, client: Retell) -> None:
        test = client.tests.create_batch_test(
            response_engine={
                "llm_id": "llm_id",
                "type": "retell-llm",
                "version": 0,
            },
            test_case_definition_ids=["string"],
            reserved_concurrency=0,
        )
        assert_matches_type(BatchTestResponse, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create_batch_test(self, client: Retell) -> None:
        response = client.tests.with_raw_response.create_batch_test(
            response_engine={
                "llm_id": "llm_id",
                "type": "retell-llm",
            },
            test_case_definition_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = response.parse()
        assert_matches_type(BatchTestResponse, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create_batch_test(self, client: Retell) -> None:
        with client.tests.with_streaming_response.create_batch_test(
            response_engine={
                "llm_id": "llm_id",
                "type": "retell-llm",
            },
            test_case_definition_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = response.parse()
            assert_matches_type(BatchTestResponse, test, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncTests:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_batch_test(self, async_client: AsyncRetell) -> None:
        test = await async_client.tests.create_batch_test(
            response_engine={
                "llm_id": "llm_id",
                "type": "retell-llm",
            },
            test_case_definition_ids=["string"],
        )
        assert_matches_type(BatchTestResponse, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_batch_test_with_all_params(self, async_client: AsyncRetell) -> None:
        test = await async_client.tests.create_batch_test(
            response_engine={
                "llm_id": "llm_id",
                "type": "retell-llm",
                "version": 0,
            },
            test_case_definition_ids=["string"],
            reserved_concurrency=0,
        )
        assert_matches_type(BatchTestResponse, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create_batch_test(self, async_client: AsyncRetell) -> None:
        response = await async_client.tests.with_raw_response.create_batch_test(
            response_engine={
                "llm_id": "llm_id",
                "type": "retell-llm",
            },
            test_case_definition_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        test = await response.parse()
        assert_matches_type(BatchTestResponse, test, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create_batch_test(self, async_client: AsyncRetell) -> None:
        async with async_client.tests.with_streaming_response.create_batch_test(
            response_engine={
                "llm_id": "llm_id",
                "type": "retell-llm",
            },
            test_case_definition_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            test = await response.parse()
            assert_matches_type(BatchTestResponse, test, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .llm import (
    LlmResource,
    AsyncLlmResource,
    LlmResourceWithRawResponse,
    AsyncLlmResourceWithRawResponse,
    LlmResourceWithStreamingResponse,
    AsyncLlmResourceWithStreamingResponse,
)
from .call import (
    CallResource,
    AsyncCallResource,
    CallResourceWithRawResponse,
    AsyncCallResourceWithRawResponse,
    CallResourceWithStreamingResponse,
    AsyncCallResourceWithStreamingResponse,
)
from .chat import (
    ChatResource,
    AsyncChatResource,
    ChatResourceWithRawResponse,
    AsyncChatResourceWithRawResponse,
    ChatResourceWithStreamingResponse,
    AsyncChatResourceWithStreamingResponse,
)
from .agent import (
    AgentResource,
    AsyncAgentResource,
    AgentResourceWithRawResponse,
    AsyncAgentResourceWithRawResponse,
    AgentResourceWithStreamingResponse,
    AsyncAgentResourceWithStreamingResponse,
)
from .tests import (
    TestsResource,
    AsyncTestsResource,
    TestsResourceWithRawResponse,
    AsyncTestsResourceWithRawResponse,
    TestsResourceWithStreamingResponse,
    AsyncTestsResourceWithStreamingResponse,
)
from .voice import (
    VoiceResource,
    AsyncVoiceResource,
    VoiceResourceWithRawResponse,
    AsyncVoiceResourceWithRawResponse,
    VoiceResourceWithStreamingResponse,
    AsyncVoiceResourceWithStreamingResponse,
)
from .mcp_tool import (
    McpToolResource,
    AsyncMcpToolResource,
    McpToolResourceWithRawResponse,
    AsyncMcpToolResourceWithRawResponse,
    McpToolResourceWithStreamingResponse,
    AsyncMcpToolResourceWithStreamingResponse,
)
from .batch_call import (
    BatchCallResource,
    AsyncBatchCallResource,
    BatchCallResourceWithRawResponse,
    AsyncBatchCallResourceWithRawResponse,
    BatchCallResourceWithStreamingResponse,
    AsyncBatchCallResourceWithStreamingResponse,
)
from .chat_agent import (
    ChatAgentResource,
    AsyncChatAgentResource,
    ChatAgentResourceWithRawResponse,
    AsyncChatAgentResourceWithRawResponse,
    ChatAgentResourceWithStreamingResponse,
    AsyncChatAgentResourceWithStreamingResponse,
)
from .concurrency import (
    ConcurrencyResource,
    AsyncConcurrencyResource,
    ConcurrencyResourceWithRawResponse,
    AsyncConcurrencyResourceWithRawResponse,
    ConcurrencyResourceWithStreamingResponse,
    AsyncConcurrencyResourceWithStreamingResponse,
)
from .phone_number import (
    PhoneNumberResource,
    AsyncPhoneNumberResource,
    PhoneNumberResourceWithRawResponse,
    AsyncPhoneNumberResourceWithRawResponse,
    PhoneNumberResourceWithStreamingResponse,
    AsyncPhoneNumberResourceWithStreamingResponse,
)
from .knowledge_base import (
    KnowledgeBaseResource,
    AsyncKnowledgeBaseResource,
    KnowledgeBaseResourceWithRawResponse,
    AsyncKnowledgeBaseResourceWithRawResponse,
    KnowledgeBaseResourceWithStreamingResponse,
    AsyncKnowledgeBaseResourceWithStreamingResponse,
)
from .conversation_flow import (
    ConversationFlowResource,
    AsyncConversationFlowResource,
    ConversationFlowResourceWithRawResponse,
    AsyncConversationFlowResourceWithRawResponse,
    ConversationFlowResourceWithStreamingResponse,
    AsyncConversationFlowResourceWithStreamingResponse,
)
from .conversation_flow_component import (
    ConversationFlowComponentResource,
    AsyncConversationFlowComponentResource,
    ConversationFlowComponentResourceWithRawResponse,
    AsyncConversationFlowComponentResourceWithRawResponse,
    ConversationFlowComponentResourceWithStreamingResponse,
    AsyncConversationFlowComponentResourceWithStreamingResponse,
)

__all__ = [
    "CallResource",
    "AsyncCallResource",
    "CallResourceWithRawResponse",
    "AsyncCallResourceWithRawResponse",
    "CallResourceWithStreamingResponse",
    "AsyncCallResourceWithStreamingResponse",
    "ChatResource",
    "AsyncChatResource",
    "ChatResourceWithRawResponse",
    "AsyncChatResourceWithRawResponse",
    "ChatResourceWithStreamingResponse",
    "AsyncChatResourceWithStreamingResponse",
    "PhoneNumberResource",
    "AsyncPhoneNumberResource",
    "PhoneNumberResourceWithRawResponse",
    "AsyncPhoneNumberResourceWithRawResponse",
    "PhoneNumberResourceWithStreamingResponse",
    "AsyncPhoneNumberResourceWithStreamingResponse",
    "AgentResource",
    "AsyncAgentResource",
    "AgentResourceWithRawResponse",
    "AsyncAgentResourceWithRawResponse",
    "AgentResourceWithStreamingResponse",
    "AsyncAgentResourceWithStreamingResponse",
    "ChatAgentResource",
    "AsyncChatAgentResource",
    "ChatAgentResourceWithRawResponse",
    "AsyncChatAgentResourceWithRawResponse",
    "ChatAgentResourceWithStreamingResponse",
    "AsyncChatAgentResourceWithStreamingResponse",
    "LlmResource",
    "AsyncLlmResource",
    "LlmResourceWithRawResponse",
    "AsyncLlmResourceWithRawResponse",
    "LlmResourceWithStreamingResponse",
    "AsyncLlmResourceWithStreamingResponse",
    "ConversationFlowResource",
    "AsyncConversationFlowResource",
    "ConversationFlowResourceWithRawResponse",
    "AsyncConversationFlowResourceWithRawResponse",
    "ConversationFlowResourceWithStreamingResponse",
    "AsyncConversationFlowResourceWithStreamingResponse",
    "ConversationFlowComponentResource",
    "AsyncConversationFlowComponentResource",
    "ConversationFlowComponentResourceWithRawResponse",
    "AsyncConversationFlowComponentResourceWithRawResponse",
    "ConversationFlowComponentResourceWithStreamingResponse",
    "AsyncConversationFlowComponentResourceWithStreamingResponse",
    "KnowledgeBaseResource",
    "AsyncKnowledgeBaseResource",
    "KnowledgeBaseResourceWithRawResponse",
    "AsyncKnowledgeBaseResourceWithRawResponse",
    "KnowledgeBaseResourceWithStreamingResponse",
    "AsyncKnowledgeBaseResourceWithStreamingResponse",
    "VoiceResource",
    "AsyncVoiceResource",
    "VoiceResourceWithRawResponse",
    "AsyncVoiceResourceWithRawResponse",
    "VoiceResourceWithStreamingResponse",
    "AsyncVoiceResourceWithStreamingResponse",
    "ConcurrencyResource",
    "AsyncConcurrencyResource",
    "ConcurrencyResourceWithRawResponse",
    "AsyncConcurrencyResourceWithRawResponse",
    "ConcurrencyResourceWithStreamingResponse",
    "AsyncConcurrencyResourceWithStreamingResponse",
    "BatchCallResource",
    "AsyncBatchCallResource",
    "BatchCallResourceWithRawResponse",
    "AsyncBatchCallResourceWithRawResponse",
    "BatchCallResourceWithStreamingResponse",
    "AsyncBatchCallResourceWithStreamingResponse",
    "TestsResource",
    "AsyncTestsResource",
    "TestsResourceWithRawResponse",
    "AsyncTestsResourceWithRawResponse",
    "TestsResourceWithStreamingResponse",
    "AsyncTestsResourceWithStreamingResponse",
    "McpToolResource",
    "AsyncMcpToolResource",
    "McpToolResourceWithRawResponse",
    "AsyncMcpToolResourceWithRawResponse",
    "McpToolResourceWithStreamingResponse",
    "AsyncMcpToolResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from retell import Retell, AsyncRetell
from tests.utils import assert_matches_type
from retell.types import (
    VoiceResponse,
    VoiceListResponse,
    VoiceSearchResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestVoice:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Retell) -> None:
        voice = client.voice.retrieve(
            "11labs-Adrian",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Retell) -> None:
        response = client.voice.with_raw_response.retrieve(
            "11labs-Adrian",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = response.parse()
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Retell) -> None:
        with client.voice.with_streaming_response.retrieve(
            "11labs-Adrian",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = response.parse()
            assert_matches_type(VoiceResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Retell) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `voice_id` but received ''"):
            client.voice.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Retell) -> None:
        voice = client.voice.list()
        assert_matches_type(VoiceListResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Retell) -> None:
        response = client.voice.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = response.parse()
        assert_matches_type(VoiceListResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Retell) -> None:
        with client.voice.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = response.parse()
            assert_matches_type(VoiceListResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_add_resource(self, client: Retell) -> None:
        voice = client.voice.add_resource(
            provider_voice_id="provider_voice_id",
            voice_name="x",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_add_resource_with_all_params(self, client: Retell) -> None:
        voice = client.voice.add_resource(
            provider_voice_id="provider_voice_id",
            voice_name="x",
            public_user_id="public_user_id",
            voice_provider="elevenlabs",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_add_resource(self, client: Retell) -> None:
        response = client.voice.with_raw_response.add_resource(
            provider_voice_id="provider_voice_id",
            voice_name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = response.parse()
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_add_resource(self, client: Retell) -> None:
        with client.voice.with_streaming_response.add_resource(
            provider_voice_id="provider_voice_id",
            voice_name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = response.parse()
            assert_matches_type(VoiceResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_clone(self, client: Retell) -> None:
        voice = client.voice.clone(
            files=[b"raw file contents"],
            voice_name="x",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_clone_with_all_params(self, client: Retell) -> None:
        voice = client.voice.clone(
            files=[b"raw file contents"],
            voice_name="x",
            voice_provider="elevenlabs",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_clone(self, client: Retell) -> None:
        response = client.voice.with_raw_response.clone(
            files=[b"raw file contents"],
            voice_name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = response.parse()
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_clone(self, client: Retell) -> None:
        with client.voice.with_streaming_response.clone(
            files=[b"raw file contents"],
            voice_name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = response.parse()
            assert_matches_type(VoiceResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_search(self, client: Retell) -> None:
        voice = client.voice.search(
            search_query="search_query",
        )
        assert_matches_type(VoiceSearchResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_search_with_all_params(self, client: Retell) -> None:
        voice = client.voice.search(
            search_query="search_query",
            voice_provider="elevenlabs",
        )
        assert_matches_type(VoiceSearchResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_search(self, client: Retell) -> None:
        response = client.voice.with_raw_response.search(
            search_query="search_query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = response.parse()
        assert_matches_type(VoiceSearchResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_search(self, client: Retell) -> None:
        with client.voice.with_streaming_response.search(
            search_query="search_query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = response.parse()
            assert_matches_type(VoiceSearchResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncVoice:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncRetell) -> None:
        voice = await async_client.voice.retrieve(
            "11labs-Adrian",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncRetell) -> None:
        response = await async_client.voice.with_raw_response.retrieve(
            "11labs-Adrian",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = await response.parse()
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncRetell) -> None:
        async with async_client.voice.with_streaming_response.retrieve(
            "11labs-Adrian",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = await response.parse()
            assert_matches_type(VoiceResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncRetell) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `voice_id` but received ''"):
            await async_client.voice.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncRetell) -> None:
        voice = await async_client.voice.list()
        assert_matches_type(VoiceListResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncRetell) -> None:
        response = await async_client.voice.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = await response.parse()
        assert_matches_type(VoiceListResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncRetell) -> None:
        async with async_client.voice.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = await response.parse()
            assert_matches_type(VoiceListResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_add_resource(self, async_client: AsyncRetell) -> None:
        voice = await async_client.voice.add_resource(
            provider_voice_id="provider_voice_id",
            voice_name="x",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_add_resource_with_all_params(self, async_client: AsyncRetell) -> None:
        voice = await async_client.voice.add_resource(
            provider_voice_id="provider_voice_id",
            voice_name="x",
            public_user_id="public_user_id",
            voice_provider="elevenlabs",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_add_resource(self, async_client: AsyncRetell) -> None:
        response = await async_client.voice.with_raw_response.add_resource(
            provider_voice_id="provider_voice_id",
            voice_name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = await response.parse()
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_add_resource(self, async_client: AsyncRetell) -> None:
        async with async_client.voice.with_streaming_response.add_resource(
            provider_voice_id="provider_voice_id",
            voice_name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = await response.parse()
            assert_matches_type(VoiceResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_clone(self, async_client: AsyncRetell) -> None:
        voice = await async_client.voice.clone(
            files=[b"raw file contents"],
            voice_name="x",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_clone_with_all_params(self, async_client: AsyncRetell) -> None:
        voice = await async_client.voice.clone(
            files=[b"raw file contents"],
            voice_name="x",
            voice_provider="elevenlabs",
        )
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_clone(self, async_client: AsyncRetell) -> None:
        response = await async_client.voice.with_raw_response.clone(
            files=[b"raw file contents"],
            voice_name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = await response.parse()
        assert_matches_type(VoiceResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_clone(self, async_client: AsyncRetell) -> None:
        async with async_client.voice.with_streaming_response.clone(
            files=[b"raw file contents"],
            voice_name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = await response.parse()
            assert_matches_type(VoiceResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_search(self, async_client: AsyncRetell) -> None:
        voice = await async_client.voice.search(
            search_query="search_query",
        )
        assert_matches_type(VoiceSearchResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_search_with_all_params(self, async_client: AsyncRetell) -> None:
        voice = await async_client.voice.search(
            search_query="search_query",
            voice_provider="elevenlabs",
        )
        assert_matches_type(VoiceSearchResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_search(self, async_client: AsyncRetell) -> None:
        response = await async_client.voice.with_raw_response.search(
            search_query="search_query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        voice = await response.parse()
        assert_matches_type(VoiceSearchResponse, voice, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_search(self, async_client: AsyncRetell) -> None:
        async with async_client.voice.with_streaming_response.search(
            search_query="search_query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            voice = await response.parse()
            assert_matches_type(VoiceSearchResponse, voice, path=["response"])

        assert cast(Any, response.is_closed) is True
